Method: Buxfer::Account#upload_statement
- Defined in:
- lib/buxfer/account.rb
#upload_statement(statement, date_format = 'DD/MM/YYYY') ⇒ Object
Upload a file containing a transaction statement to Buxfer account.
The statement can be a String or an IO object.
An optional date format can be passed indicating if the dates used in the statement are in the format ‘DD/MM/YYYY’ (default) or ‘MM/DD/YYYY’
Example:
account = Buxfer.accounts.first
account.upload_statement(open('/path/to/file')) => true
45 46 47 |
# File 'lib/buxfer/account.rb', line 45 def upload_statement(statement, date_format = 'DD/MM/YYYY') Buxfer.upload_statement(self.id, statement, date_format) end |